@@ -1,10 +1,10 @@
 package Forest::Tree::Builder::Callback;
 use Moose::Role;
 
-our $VERSION   = '0.08';
+our $VERSION   = '0.09';
 our $AUTHORITY = 'cpan:STEVAN';
 
-with 'Forest::Tree::Builder' => { excludes => [qw(create_new_subtree)] };
+with 'Forest::Tree::Builder' => { -excludes => [qw(create_new_subtree)] };
 
 has new_subtree_callback => (
     isa => "CodeRef|Str",
